bb002 test

## B1

### A01

Description
  A01 must exists.
Depends on:
  M
Dependent
  B01
Id
  A01
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A02

Description
  A02 must exists.
Depends on:
  M
Dependent
  B01
Id
  A02
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A03

Description
  A03 must exists.
Depends on:
  M
Dependent
  B01
Id
  A03
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A04

Description
  A04 must exists.
Depends on:
  M
Dependent
  B01
Id
  A04
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A05

Description
  A05 must exists.
Depends on:
  M
Dependent
  B01
Id
  A05
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A06

Description
  A06 must exists.
Depends on:
  M
Dependent
  B01
Id
  A06
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A07

Description
  A07 must exists.
Depends on:
  M
Dependent
  B01
Id
  A07
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A08

Description
  A08 must exists.
Depends on:
  M
Dependent
  B01
Id
  A08
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A09

Description
  A09 must exists.
Depends on:
  M
Dependent
  B01
Id
  A09
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A10

Description
  A10 must exists.
Depends on:
  M
Dependent
  B01
Id
  A10
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A11

Description
  A11 must exists.
Depends on:
  M
Dependent
  B01
Id
  A11
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### A12

Description
  A12 must exists.
Depends on:
  M
Dependent
  B01
Id
  A12
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### B01

Description
  B01 must exists.
Depends on:
  A01, A02, A03, A04, A05, A06, A07, A08, A09, A10, A11, A12
Dependent
  C01, C02, C03, C04, C05, C06, C07, C08, C09, C10, C11, C12, C13, C14, C15
Id
  B01
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C01

Description
  C01 must exists.
Depends on:
  B01
Id
  C01
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C02

Description
  C02 must exists.
Depends on:
  B01
Id
  C02
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C03

Description
  C03 must exists.
Depends on:
  B01
Id
  C03
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C04

Description
  C04 must exists.
Depends on:
  B01
Id
  C04
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C05

Description
  C05 must exists.
Depends on:
  B01
Id
  C05
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C06

Description
  C06 must exists.
Depends on:
  B01
Id
  C06
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C07

Description
  C07 must exists.
Depends on:
  B01
Id
  C07
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  finished (None, , None h)
Class
  detailable

### C08

Description
  C08 must exists.
Depends on:
  B01
Id
  C08
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C09

Description
  C09 must exists.
Depends on:
  B01
Id
  C09
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C10

Description
  C10 must exists.
Depends on:
  B01
Id
  C10
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C11

Description
  C11 must exists.
Depends on:
  B01
Id
  C11
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C12

Description
  C12 must exists.
Depends on:
  B01
Id
  C12
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C13

Description
  C13 must exists.
Depends on:
  B01
Id
  C13
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C14

Description
  C14 must exists.
Depends on:
  B01
Id
  C14
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### C15

Description
  C15 must exists.
Depends on:
  B01
Id
  C15
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable

### M

Description
  M must exists.
Dependent
  A01, A02, A03, A04, A05, A06, A07, A08, A09, A10, A11, A12
Id
  M
Priority
  10.00
Owner
  development
Invented on
  2010-07-31
Invented by
  flonatel
Status
  not done
Class
  detailable